/* Copyright (c) 2013 Nordic Semiconductor. All Rights Reserved.
 *
 * Use of this source code is governed by a BSD-style license that can be
 * found in the license.txt file.
 */

#ifndef BLE_TEMPERATURE_H__
#define BLE_TEMPERATURE_H__

#include <stdint.h>
#include <stdbool.h>
#include "ble.h"
#include "ble_srv_common.h"

#define TEMPERATURE_UUID_BASE {0x23, 0xD2, 0xBC, 0xDB, 0x5F, 0x78, 0x12, 0x15, 0xDE, 0x45, 0x12, 0x12, 0x00, 0x00, 0x00, 0x00}
#define TEMPERATURE_UUID_SERVICE 0x1623
#define TEMPERATURE_UUID_TEMPERATURE_CHAR 0x1624

typedef enum
{
    BLE_TEMPERATURE_EVT_NOTIFICATION_ENABLED,                             /**< Battery value notification enabled event. */
    BLE_TEMPERATURE_EVT_NOTIFICATION_DISABLED                             /**< Battery value notification disabled event. */
} ble_temperature_evt_type_t;

typedef struct
{
    ble_temperature_evt_type_t evt_type;                                  /**< Type of event. */
} ble_temperature_evt_t;

// Forward declaration of the ble_temperature_t type. 
typedef struct ble_temperature_s ble_temperature_t;

typedef void (*ble_temperature_event_handler_t) (ble_temperature_t * p_bas, ble_temperature_evt_t * p_evt);

typedef struct
{
	  ble_temperature_event_handler_t         evt_handler;
    bool                          support_notification;    
		ble_srv_cccd_security_mode_t 			temperature_attr_md;
} ble_temperature_init_t;

/**@brief LED Button Service structure. This contains various status information for the service. */
typedef struct ble_temperature_s
{
		ble_temperature_event_handler_t   evt_handler;	
    uint16_t                    			service_handle;
    uint8_t                     			uuid_type;
    uint16_t                    			conn_handle;
    ble_gatts_char_handles_t      temperature_handles;	
		bool                          is_notification_supported;
} ble_temperature_t;

/**@brief Function for initializing the LED Button Service.
 *
 * @param[out]  p_lbs       LED Button Service structure. This structure will have to be supplied by
 *                          the application. It will be initialized by this function, and will later
 *                          be used to identify this particular service instance.
 * @param[in]   p_lbs_init  Information needed to initialize the service.
 *
 * @return      NRF_SUCCESS on successful initialization of service, otherwise an error code.
 */
uint32_t ble_temperature_init(ble_temperature_t * p_lbs, const ble_temperature_init_t * p_lbs_init);

/**@brief Function for handling the Application's BLE Stack events.
 *
 * @details Handles all events from the BLE stack of interest to the LED Button Service.
 *
 *
 * @param[in]   p_lbs      LED Button Service structure.
 * @param[in]   p_ble_evt  Event received from the BLE stack.
 */
void ble_temperature_on_ble_evt(ble_temperature_t * p_lbs, ble_evt_t * p_ble_evt);

/**@brief Function for sending a temperature notification.
 */
uint32_t ble_temperature_measurement_update(ble_temperature_t * p_temperature, uint16_t temperature);
#endif // BLE_TEMPERATURE_H__

/** @} */
